@@ -234,9 +234,9 @@ sub _markup_lang {
   my $post = shift;
   my $floor = $post->{floor};
   my $markup_lang;
-  if ($post->{'markup'} and $post->{'markup'} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
+  if ($post->{_markup} and $post->{_markup} =~ /^(markdown|md|html|text|txt|bbcode|textile)$/i)
   {
-    $markup_lang = $post->{'markup'};
+    $markup_lang = $post->{_markup};
   } elsif (
     $config->{$floor} and
     $config->{$floor}->{default_markup} and
