@@ -18,14 +18,24 @@ sub replace {
     my $source = $1 if $1;
     my $alt = $2 if $2;
     my $title = $3 ? $3 : ($2 ? $2 : '');
+    next unless $source;
+
+    if ($source =~ m{^(.*?)//})
+    {
+      $imgurl = $source;
+    } else
+    {
+      $imgurl .= "/$source" ;
+    }
 #    my $title = $2 if (! $3 and $2);
-    my $addr = "<img src=\"$imgurl";
-    $addr .= "/$source\"" if $source;
-    $addr .= "\"" unless $source;
+    my $addr = "<img src=\"$imgurl\"";
+#    $addr .= "$source\"" if $source;
+#    $addr .= "\"" unless $source;
     $addr .= " alt=$alt" if $alt;
     $addr .= " title=$title" if $title;
     $addr .= " >";
-    $addr =~ s"(?<!http:)/+"/"g;
+    $addr =~ s"(?<!:)/+"/"g;
+    say $addr;
     $self =~ s/(?<!\\)\{\{\s+img\s+([^\s]*?)\s*(".*?")?\s*(".*?")?\s*\}\}/$addr/;
   }
 
